@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class BanConfig(AppConfig):
-    name = 'ban'
+    name = 'Iuno.ban'
