@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Backends.py 13428 2022-04-25 17:43:01Z Jason $
+# $Id: Backends.py 13438 2022-04-27 06:01:35Z Jason $
 #
 # Copyright (c) 2021 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Jason $
-# $Date: 2022-04-26 01:43:01 +0800 (Tue, 26 Apr 2022) $
-# $Revision: 13428 $
+# $Date: 2022-04-27 14:01:35 +0800 (Wed, 27 Apr 2022) $
+# $Revision: 13438 $
 
 import re
 import json
@@ -24,6 +24,7 @@ from passlib.apache import HtpasswdFile
 
 from django.conf import settings
 from django.core.exceptions import PermissionDenied
+from django.contrib import messages
 from django.contrib.auth.backends import ModelBackend
 from django.contrib.auth.models import User
 DEFAULT_TRAC_AUTH_URL = getattr(settings, 
@@ -37,7 +38,7 @@ USER_DATA_PATTERN = r"#\s+?(\w+):\s+?(\{.+\}?)"
   
 class TracBackend(ModelBackend):
 
-    def check(self, username, password, tracAuthURL=DEFAULT_TRAC_AUTH_URL, 
+    def check(self, request, username, password, tracAuthURL=DEFAULT_TRAC_AUTH_URL, 
         tracUsername=DEFAULT_TRAC_AUTH_USERNAME, tracPassword=DEFAULT_TRAC_AUTH_PASSWORD):
         r = requests.get(tracAuthURL, auth=(tracUsername, tracPassword))
         content = r.text.strip()
@@ -47,17 +48,21 @@ class TracBackend(ModelBackend):
         user = data.get(username)
         if user:
             if not user.get("email"):
-                raise PermissionDenied("No email in htfile for %s" % username)
+                message = "No email in htfile for %s" % username
+                messages.add_message(request, messages.ERROR, message)
+                raise PermissionDenied()
             else:
                 email = user.get("email")
             if ht.check_password(username, password):
                 return (True, email)
         else:
-            raise PermissionDenied("No such user, please try again")
+            message = "No such user, please try again"
+            messages.add_message(request, messages.ERROR, message)
+            raise PermissionDenied()
         return (False, None)
 
     def authenticate(self, request, username=None, password=None, **kwargs):
-        valid, email = self.check(username, password)
+        valid, email = self.check(request, username, password)
         if valid:
             try:
                 user = User.objects.get(username=username)
